==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/event/ConnectionEvent.h <==
// public class gnu.java.net.protocol.http.event.ConnectionEvent

// class file dependencies
// @dep_class 5ee46b8193a02b4c gnu_java_net_protocol_http_event_ConnectionEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_gnu_java_net_protocol_http_event_ConnectionEvent_H_
#define _JC_gnu_java_net_protocol_http_event_ConnectionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_refs	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_nonrefs	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$refs	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$refs;
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$nonrefs	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$object;

typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$fields_struct	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vmethods	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtable	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$fields_struct {
	jint	CONNECTION__5fCLOSED;
};
extern _jc_gnu_java_net_protocol_http_event_ConnectionEvent$fields_struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_http_event_ConnectionEvent$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern jint _jc_gnu_java_net_protocol_http_event_ConnectionEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_event_ConnectionEvent$method_info$getType$74c20eac6b18d047;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vmethods {
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vmethods	gnu_java_net_protocol_http_event_ConnectionEvent;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$refs {
    _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_refs	gnu_java_net_protocol_http_event_ConnectionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_nonrefs	gnu_java_net_protocol_http_event_ConnectionEvent;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object {
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype _jc_gnu_java_net_protocol_http_event_ConnectionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_event_ConnectionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_event_ConnectionEvent$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_event_ConnectionEvent_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/event/ConnectionEvent.h <==
// public class gnu.java.net.protocol.http.event.ConnectionEvent

// class file dependencies
// @dep_class 5ee46b8193a02b4c gnu_java_net_protocol_http_event_ConnectionEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_gnu_java_net_protocol_http_event_ConnectionEvent_H_
#define _JC_gnu_java_net_protocol_http_event_ConnectionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_refs	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_nonrefs	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$refs	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$refs;
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$nonrefs	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$object;

typedef struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$fields_struct	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vmethods	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtable	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$fields_struct {
	jint	CONNECTION__5fCLOSED;
};
extern _jc_gnu_java_net_protocol_http_event_ConnectionEvent$fields_struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_http_event_ConnectionEvent$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_protocol_http_event_ConnectionEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_event_ConnectionEvent$method_info$getType$74c20eac6b18d047;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vmethods {
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vmethods	gnu_java_net_protocol_http_event_ConnectionEvent;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$refs {
    _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_refs	gnu_java_net_protocol_http_event_ConnectionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_gnu_java_net_protocol_http_event_ConnectionEvent$sub_nonrefs	gnu_java_net_protocol_http_event_ConnectionEvent;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_event_ConnectionEvent$object {
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_event_ConnectionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_event_ConnectionEvent$vtype _jc_gnu_java_net_protocol_http_event_ConnectionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_event_ConnectionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_event_ConnectionEvent$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_event_ConnectionEvent_H_ */
